@@ -166,7 +166,13 @@ else:
 # may have trouble processing.
 MATCHES_LIMIT = 500
 
-_deprecation_readline_sentinel = object()
+
+class Sentinel:
+    def __repr__(self):
+        return "<deprecated sentinel>"
+
+
+_deprecation_readline_sentinel = Sentinel()
 
 
 class ProvisionalCompleterWarning(FutureWarning):
@@ -193,7 +199,9 @@ def provisionalcompleter(action='ignore'):
 
     >>> completer.do_experimental_things() # raises.
 
-    .. note:: Unstable
+    .. note::
+
+        Unstable
 
         By using this context manager you agree that the API in use may change
         without warning, and that you won't complain if they do so.
@@ -348,7 +356,9 @@ class Completion:
     """
     Completion object used and return by IPython completers.
 
-    .. warning:: Unstable
+    .. warning::
+
+        Unstable
 
         This function is unstable, API may change without warning.
         It will also raise unless use in proper context manager.
@@ -411,7 +421,9 @@ def _deduplicate_completions(text: str, completions: _IC)-> _IC:
     """
     Deduplicate a set of completions.
 
-    .. warning:: Unstable
+    .. warning::
+
+        Unstable
 
         This function is unstable, API may change without warning.
 
@@ -454,7 +466,9 @@ def rectify_completions(text: str, completions: _IC, *, _debug=False)->_IC:
     """
     Rectify a set of completions to all have the same ``start`` and ``end``
 
-    .. warning:: Unstable
+    .. warning::
+
+        Unstable
 
         This function is unstable, API may change without warning.
         It will also raise unless use in proper context manager.
@@ -1135,18 +1149,18 @@ class IPCompleter(Completer):
         if self.use_jedi:
             return [
                 *self.custom_matchers,
+                self.dict_key_matches,
                 self.file_matches,
                 self.magic_matches,
-                self.dict_key_matches,
             ]
         else:
             return [
                 *self.custom_matchers,
+                self.dict_key_matches,
                 self.python_matches,
                 self.file_matches,
                 self.magic_matches,
                 self.python_func_kw_matches,
-                self.dict_key_matches,
             ]
 
     def all_completions(self, text) -> List[str]:
@@ -1488,7 +1502,7 @@ class IPCompleter(Completer):
                   inspect.Parameter.POSITIONAL_OR_KEYWORD)
 
         try:
-            sig = inspect.signature(call_obj)
+            sig = inspect.signature(obj)
             ret.extend(k for k, v in sig.parameters.items() if
                        v.kind in _keeps)
         except ValueError:
@@ -1776,7 +1790,9 @@ class IPCompleter(Completer):
         """
         Returns an iterator over the possible completions
 
-        .. warning:: Unstable
+        .. warning::
+
+            Unstable
 
             This function is unstable, API may change without warning.
             It will also raise unless use in proper context manager.
