@@ -1,35 +1,20 @@
 # -*- coding: utf-8 -*-
-"""Tests for the inputsplitter module.
+"""Tests for the inputsplitter module."""
 
-Authors
--------
-* Fernando Perez
-* Robert Kern
-"""
-from __future__ import print_function
-#-----------------------------------------------------------------------------
-#  Copyright (C) 2010-2011  The IPython Development Team
-#
-#  Distributed under the terms of the BSD License.  The full license is in
-#  the file COPYING, distributed as part of this software.
-#-----------------------------------------------------------------------------
 
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
-# stdlib
+# Copyright (c) IPython Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 import unittest
 import sys
 
-# Third party
 import nose.tools as nt
 
-# Our own
 from IPython.core import inputsplitter as isp
+from IPython.core.inputtransformer import InputTransformer
 from IPython.core.tests.test_inputtransformer import syntax, syntax_ml
 from IPython.testing import tools as tt
-from IPython.utils import py3compat
-from IPython.utils.py3compat import string_types, input
+from IPython.testing.decorators import skipif
 
 #-----------------------------------------------------------------------------
 # Semi-complete examples (also used as tests)
@@ -51,7 +36,7 @@ def mini_interactive_loop(input_func):
     # input indefinitely, until some exit/quit command was issued.  Here we
     # only illustrate the basic inner loop.
     while isp.push_accepts_more():
-        indent = ' '*isp.indent_spaces
+        indent = ' '*isp.get_indent_spaces()
         prompt = '>>> ' + indent
         line = indent + input_func(prompt)
         isp.push(line)
@@ -114,7 +99,7 @@ def test_remove_comments():
 
 def test_get_input_encoding():
     encoding = isp.get_input_encoding()
-    nt.assert_true(isinstance(encoding, string_types))
+    nt.assert_true(isinstance(encoding, str))
     # simple-minded check that at least encoding a simple string works with the
     # encoding we got.
     nt.assert_equal(u'test'.encode(encoding), b'test')
@@ -146,7 +131,7 @@ class InputSplitterTestCase(unittest.TestCase):
         isp.push('x=1')
         isp.reset()
         self.assertEqual(isp._buffer, [])
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         self.assertEqual(isp.source, '')
         self.assertEqual(isp.code, None)
         self.assertEqual(isp._is_complete, False)
@@ -155,7 +140,7 @@ class InputSplitterTestCase(unittest.TestCase):
         self.isp._store('1')
         self.isp._store('2')
         self.assertEqual(self.isp.source, '1\n2\n')
-        self.assertTrue(len(self.isp._buffer)>0)
+        self.assertEqual(len(self.isp._buffer)>0, True)
         self.assertEqual(self.isp.source_reset(), '1\n2\n')
         self.assertEqual(self.isp._buffer, [])
         self.assertEqual(self.isp.source, '')
@@ -163,21 +148,21 @@ class InputSplitterTestCase(unittest.TestCase):
     def test_indent(self):
         isp = self.isp # shorthand
         isp.push('x=1')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\n    x=1')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('y=2\n')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
 
     def test_indent2(self):
         isp = self.isp
         isp.push('if 1:')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('    x=1')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         # Blank lines shouldn't change the indent level
         isp.push(' '*2)
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
 
     def test_indent3(self):
         isp = self.isp
@@ -185,111 +170,111 @@ class InputSplitterTestCase(unittest.TestCase):
         # shouldn't get confused.
         isp.push("if 1:")
         isp.push("    x = (1+\n    2)")
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
 
     def test_indent4(self):
         isp = self.isp
         # whitespace after ':' should not screw up indent level
         isp.push('if 1: \n    x=1')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('y=2\n')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\t\n    x=1')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('y=2\n')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
 
     def test_dedent_pass(self):
         isp = self.isp # shorthand
         # should NOT cause dedent
         isp.push('if 1:\n    passes = 5')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('if 1:\n     pass')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\n     pass   ')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
 
     def test_dedent_break(self):
         isp = self.isp # shorthand
         # should NOT cause dedent
         isp.push('while 1:\n    breaks = 5')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('while 1:\n     break')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('while 1:\n     break   ')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
 
     def test_dedent_continue(self):
         isp = self.isp # shorthand
         # should NOT cause dedent
         isp.push('while 1:\n    continues = 5')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('while 1:\n     continue')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('while 1:\n     continue   ')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
 
     def test_dedent_raise(self):
         isp = self.isp # shorthand
         # should NOT cause dedent
         isp.push('if 1:\n    raised = 4')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('if 1:\n     raise TypeError()')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\n     raise')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\n     raise      ')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
 
     def test_dedent_return(self):
         isp = self.isp # shorthand
         # should NOT cause dedent
         isp.push('if 1:\n    returning = 4')
-        self.assertEqual(isp.indent_spaces, 4)
+        self.assertEqual(isp.get_indent_spaces(), 4)
         isp.push('if 1:\n     return 5 + 493')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\n     return')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\n     return      ')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
         isp.push('if 1:\n     return(0)')
-        self.assertEqual(isp.indent_spaces, 0)
+        self.assertEqual(isp.get_indent_spaces(), 0)
 
     def test_push(self):
         isp = self.isp
-        self.assertTrue(isp.push('x=1'))
+        self.assertEqual(isp.push('x=1'), True)
 
     def test_push2(self):
         isp = self.isp
-        self.assertFalse(isp.push('if 1:'))
+        self.assertEqual(isp.push('if 1:'), False)
         for line in ['  x=1', '# a comment', '  y=2']:
             print(line)
-            self.assertTrue(isp.push(line))
+            self.assertEqual(isp.push(line), True)
 
     def test_push3(self):
         isp = self.isp
         isp.push('if True:')
         isp.push('  a = 1')
-        self.assertFalse(isp.push('b = [1,'))
+        self.assertEqual(isp.push('b = [1,'), False)
 
     def test_push_accepts_more(self):
         isp = self.isp
         isp.push('x=1')
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
 
     def test_push_accepts_more2(self):
         isp = self.isp
         isp.push('if 1:')
-        self.assertTrue(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), True)
         isp.push('  x=1')
-        self.assertTrue(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), True)
         isp.push('')
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
 
     def test_push_accepts_more3(self):
         isp = self.isp
         isp.push("x = (2+\n3)")
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
 
     def test_push_accepts_more4(self):
         isp = self.isp
@@ -303,11 +288,11 @@ class InputSplitterTestCase(unittest.TestCase):
         isp.push("if 1:")
         isp.push("    x = (2+")
         isp.push("    3)")
-        self.assertTrue(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), True)
         isp.push("    y = 3")
-        self.assertTrue(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), True)
         isp.push('')
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
 
     def test_push_accepts_more5(self):
         isp = self.isp
@@ -317,14 +302,14 @@ class InputSplitterTestCase(unittest.TestCase):
         isp.push('    raise')
         # We want to be able to add an else: block at this point, so it should
         # wait for a blank line.
-        self.assertTrue(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), True)
 
     def test_continuation(self):
         isp = self.isp
         isp.push("import os, \\")
-        self.assertTrue(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), True)
         isp.push("sys")
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
 
     def test_syntax_error(self):
         isp = self.isp
@@ -332,28 +317,37 @@ class InputSplitterTestCase(unittest.TestCase):
         # Python can be sent to the kernel for evaluation with possible ipython
         # special-syntax conversion.
         isp.push('run foo')
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
 
     def test_unicode(self):
         self.isp.push(u"Pérez")
         self.isp.push(u'\xc3\xa9')
         self.isp.push(u"u'\xc3\xa9'")
 
+    @skipif(sys.version_info[:3] == (3, 9, 8))
     def test_line_continuation(self):
         """ Test issue #2108."""
         isp = self.isp
         # A blank line after a line continuation should not accept more
         isp.push("1 \\\n\n")
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
         # Whitespace after a \ is a SyntaxError.  The only way to test that
         # here is to test that push doesn't accept more (as with
         # test_syntax_error() above).
         isp.push(r"1 \ ")
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
         # Even if the line is continuable (c.f. the regular Python
         # interpreter)
         isp.push(r"(1 \ ")
-        self.assertFalse(isp.push_accepts_more())
+        self.assertEqual(isp.push_accepts_more(), False)
+
+    def test_check_complete(self):
+        isp = self.isp
+        self.assertEqual(isp.check_complete("a = 1"), ('complete', None))
+        self.assertEqual(isp.check_complete("for a in range(5):"), ('incomplete', 4))
+        self.assertEqual(isp.check_complete("raise = 2"), ('invalid', None))
+        self.assertEqual(isp.check_complete("a = [1,\n2,"), ('incomplete', 0))
+        self.assertEqual(isp.check_complete("def a():\n x=1\n global x"), ('invalid', None))
 
 class InteractiveLoopTestCase(unittest.TestCase):
     """Tests for an interactive loop like a python shell.
@@ -455,9 +449,9 @@ class IPythonInputTestCase(InputSplitterTestCase):
         isp = self.isp
         for raw, name, line, cell in [
             ("%%cellm a\nIn[1]:", u'cellm', u'a', u'In[1]:'),
-            ("%%cellm \nline\n>>>hi", u'cellm', u'', u'line\n>>>hi'),
-            (">>>%%cellm \nline\n>>>hi", u'cellm', u'', u'line\nhi'),
-            ("%%cellm \n>>>hi", u'cellm', u'', u'hi'),
+            ("%%cellm \nline\n>>> hi", u'cellm', u'', u'line\n>>> hi'),
+            (">>> %%cellm \nline\n>>> hi", u'cellm', u'', u'line\nhi'),
+            ("%%cellm \n>>> hi", u'cellm', u'', u'>>> hi'),
             ("%%cellm \nline1\nline2", u'cellm', u'', u'line1\nline2'),
             ("%%cellm \nline1\\\\\nline2", u'cellm', u'', u'line1\\\\\nline2'),
         ]:
@@ -466,8 +460,33 @@ class IPythonInputTestCase(InputSplitterTestCase):
             )
             out = isp.transform_cell(raw)
             self.assertEqual(out.rstrip(), expected.rstrip())
+
+    def test_multiline_passthrough(self):
+        isp = self.isp
+        class CommentTransformer(InputTransformer):
+            def __init__(self):
+                self._lines = []
+            
+            def push(self, line):
+                self._lines.append(line + '#')
+            
+            def reset(self):
+                text = '\n'.join(self._lines)
+                self._lines = []
+                return text
         
+        isp.physical_line_transforms.insert(0, CommentTransformer())
         
+        for raw, expected in [
+            ("a=5", "a=5#"),
+            ("%ls foo", "get_ipython().run_line_magic(%r, %r)" % (u'ls', u'foo#')),
+            ("!ls foo\n%ls bar", "get_ipython().system(%r)\nget_ipython().run_line_magic(%r, %r)" % (
+                u'ls foo#', u'ls', u'bar#'
+            )),
+            ("1\n2\n3\n%ls foo\n4\n5", "1#\n2#\n3#\nget_ipython().run_line_magic(%r, %r)\n4#\n5#" % (u'ls', u'foo#')),
+        ]:
+            out = isp.transform_cell(raw)
+            self.assertEqual(out.rstrip(), expected.rstrip())
 
 #-----------------------------------------------------------------------------
 # Main - use as a script, mostly for developer experiments
@@ -476,7 +495,7 @@ class IPythonInputTestCase(InputSplitterTestCase):
 if __name__ == '__main__':
     # A simple demo for interactive experimentation.  This code will not get
     # picked up by any test suite.
-    from IPython.core.inputsplitter import InputSplitter, IPythonInputSplitter
+    from IPython.core.inputsplitter import IPythonInputSplitter
 
     # configure here the syntax to use, prompt and whether to autoindent
     #isp, start_prompt = InputSplitter(), '>>> '
@@ -489,7 +508,7 @@ if __name__ == '__main__':
         while True:
             prompt = start_prompt
             while isp.push_accepts_more():
-                indent = ' '*isp.indent_spaces
+                indent = ' '*isp.get_indent_spaces()
                 if autoindent:
                     line = indent + input(prompt+indent)
                 else:
@@ -549,8 +568,8 @@ class CellMagicsCommon(object):
     def test_whole_cell(self):
         src = "%%cellm line\nbody\n"
         out = self.sp.transform_cell(src)
-        ref = u"get_ipython().run_cell_magic({u}'cellm', {u}'line', {u}'body')\n"
-        nt.assert_equal(out, py3compat.u_format(ref))
+        ref = "get_ipython().run_cell_magic('cellm', 'line', 'body')\n"
+        nt.assert_equal(out, ref)
     
     def test_cellmagic_help(self):
         self.sp.push('%%cellm?')
@@ -572,6 +591,16 @@ class CellModeCellMagics(CellMagicsCommon, unittest.TestCase):
         sp.push('\n')
         # This should accept a blank line and carry on until the cell is reset
         nt.assert_true(sp.push_accepts_more()) #3
+    
+    def test_no_strip_coding(self):
+        src = '\n'.join([
+            '%%writefile foo.py',
+            '# coding: utf-8',
+            'print(u"üñîçø∂é")',
+        ])
+        out = self.sp.transform_cell(src)
+        nt.assert_in('# coding: utf-8', out)
+
 
 class LineModeCellMagics(CellMagicsCommon, unittest.TestCase):
     sp = isp.IPythonInputSplitter(line_input_checker=True)
@@ -583,3 +612,30 @@ class LineModeCellMagics(CellMagicsCommon, unittest.TestCase):
         sp.push('\n')
         # In this case, a blank line should end the cell magic
         nt.assert_false(sp.push_accepts_more()) #2
+
+indentation_samples = [
+    ('a = 1', 0),
+    ('for a in b:', 4),
+    ('def f():', 4),
+    ('def f(): #comment', 4),
+    ('a = ":#not a comment"', 0),
+    ('def f():\n    a = 1', 4),
+    ('def f():\n    return 1', 0),
+    ('for a in b:\n'
+     '   if a < 0:'
+     '       continue', 3),
+    ('a = {', 4),
+    ('a = {\n'
+     '     1,', 5),
+    ('b = """123', 0),
+    ('', 0),
+    ('def f():\n    pass', 0),
+    ('class Bar:\n    def f():\n        pass', 4),
+    ('class Bar:\n    def f():\n        raise', 4),
+]
+
+def test_find_next_indent():
+    for code, exp in indentation_samples:
+        res = isp.find_next_indent(code)
+        msg = "{!r} != {!r} (expected)\n Code: {!r}".format(res, exp, code)
+        assert res == exp, msg
