@@ -1,7 +1,8 @@
 # coding: utf-8
-from IPython.core.splitinput import split_user_input
+import nose.tools as nt
+
+from IPython.core.splitinput import split_user_input, LineInfo
 from IPython.testing import tools as tt
-from IPython.utils import py3compat
 
 tests = [
     ('x=1', ('', '', 'x', '=1')),
@@ -26,10 +27,12 @@ tests = [
     ('??%%hist4', ('', '??', '%%hist4', '')),
     ('?x*', ('', '?', 'x*', '')),
     ]
-if py3compat.PY3:
-    tests.append((u"Pérez Fernando", (u'', u'', u'Pérez', u'Fernando')))
-else:
-    tests.append((u"Pérez Fernando", (u'', u'', u'P', u'érez Fernando')))
+tests.append((u"Pérez Fernando", (u'', u'', u'Pérez', u'Fernando')))
 
 def test_split_user_input():
     return tt.check_pairs(split_user_input, tests)
+
+def test_LineInfo():
+    """Simple test for LineInfo construction and str()"""
+    linfo = LineInfo('  %cd /home')
+    nt.assert_equal(str(linfo), 'LineInfo [  |%|cd|/home]')
