@@ -3,23 +3,21 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from __future__ import absolute_import, print_function
-
 from collections import namedtuple
 from io import StringIO
 from keyword import iskeyword
 
-from . import tokenize2
-from .py3compat import cast_unicode_py2
+import tokenize
+
 
 Token = namedtuple('Token', ['token', 'text', 'start', 'end', 'line'])
 
 def generate_tokens(readline):
     """wrap generate_tokens to catch EOF errors"""
     try:
-        for token in tokenize2.generate_tokens(readline):
+        for token in tokenize.generate_tokens(readline):
             yield token
-    except tokenize2.TokenError:
+    except tokenize.TokenError:
         # catch EOF error
         return
 
@@ -39,14 +37,19 @@ def line_at_cursor(cell, cursor_pos=0):
     Returns
     -------
     
-    (line, offset): (text, integer)
+    (line, offset): (string, integer)
         The line with the current cursor, and the character offset of the start of the line.
     """
     offset = 0
     lines = cell.splitlines(True)
     for line in lines:
         next_offset = offset + len(line)
-        if next_offset >= cursor_pos:
+        if not line.endswith('\n'):
+            # If the last line doesn't have a trailing newline, treat it as if
+            # it does so that the cursor at the end of the line still counts
+            # as being on that line.
+            next_offset += 1
+        if next_offset > cursor_pos:
             break
         offset = next_offset
     else:
@@ -69,7 +72,6 @@ def token_at_cursor(cell, cursor_pos=0):
     cursor_pos : int
         The location of the cursor in the block where the token should be found
     """
-    cell = cast_unicode_py2(cell)
     names = []
     tokens = []
     call_names = []
@@ -85,7 +87,7 @@ def token_at_cursor(cell, cursor_pos=0):
         if end_line + 1 not in offsets:
             # keep track of offsets for each line
             lines = tok.line.splitlines(True)
-            for lineno, line in zip(range(start_line + 1, end_line + 2), lines):
+            for lineno, line in enumerate(lines, start_line + 1):
                 if lineno not in offsets:
                     offsets[lineno] = offsets[lineno-1] + len(line)
         
@@ -97,12 +99,12 @@ def token_at_cursor(cell, cursor_pos=0):
             # don't consume it
             break
         
-        if tok.token == tokenize2.NAME and not iskeyword(tok.text):
-            if names and tokens and tokens[-1].token == tokenize2.OP and tokens[-1].text == '.':
+        if tok.token == tokenize.NAME and not iskeyword(tok.text):
+            if names and tokens and tokens[-1].token == tokenize.OP and tokens[-1].text == '.':
                 names[-1] = "%s.%s" % (names[-1], tok.text)
             else:
                 names.append(tok.text)
-        elif tok.token == tokenize2.OP:
+        elif tok.token == tokenize.OP:
             if tok.text == '=' and names:
                 # don't inspect the lhs of an assignment
                 names.pop(-1)
